==> haskell-crypto-pubkey-types-0.4.3-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-DMY9IGdvOgj5sj3QdfWaF3
key: crypto-pubkey-types-0.4.3-DMY9IGdvOgj5sj3QdfWaF3
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: 7e8e87e15c7131fc24be521f25748f60
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-DMY9IGdvOgj5sj3QdfWaF3
depends:
    asn1-encoding-0.9.5-CVAJwfXBBy32v2S991bpT7
    asn1-types-0.3.2-KLmYgaafoKXEmGB31FMlKz base-4.11.1.0
abi-depends: asn1-encoding-0.9.5-CVAJwfXBBy32v2S991bpT7=85b5a949c9e94818387138acf6fa1bce
             asn1-types-0.3.2-KLmYgaafoKXEmGB31FMlKz=50cb2ffa2f744a3e0846b2c42242d6d1
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-63-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-DDhDciZOiDm4G4LZwuUaG3
key: crypto-pubkey-types-0.4.3-DDhDciZOiDm4G4LZwuUaG3
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: faaf7b9ef6354b1f10f3d339168a7f80
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-DDhDciZOiDm4G4LZwuUaG3
depends:
    asn1-encoding-0.9.5-D6wKH3oeWgmIGlgRzG9HDX
    asn1-types-0.3.2-APLQoNROQGmB0wmh7tzA2H base-4.11.1.0
abi-depends: asn1-encoding-0.9.5-D6wKH3oeWgmIGlgRzG9HDX=1126404f31e4ae6f8da3d47fe6a6b433
             asn1-types-0.3.2-APLQoNROQGmB0wmh7tzA2H=02576d862bb6ac63ddf066c176cc45e8
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
